﻿/*
 *
 *
 *    RadioFlDigi.cs
 *
 *    AutoCap radio module for FlDigi.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2014-2018 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

#if DEBUG
// define this to make the debug output chat about the motor command progress
#define VERBOSE_DEBUG
#endif

using System;
using KK5JY.RadioSupport;
using System.Threading;
using System.Diagnostics;

namespace KK5JY.AutoCap {
	/// <summary>
	/// Interface object for FlDigi.
	/// </summary>
	public class RadioFlDigi : IRadio, IReportsVersion, IDisposable {
		#region Private Fields
		private FlDigi m_Radio;
		private Thread m_Thread;
		private string m_Host;
		private bool m_Quit;
		#endregion

		#region Public Properties
		/// <summary>
		/// Return the frequency.
		/// </summary>
		public decimal Frequency { get; private set; }

		/// <summary>
		/// Get the version string.
		/// </summary>
		public string VersionString { get { return "AutoCap Interface for FlDigi XMLRPC"; } }
		#endregion

		#region Public Methods
		/// <summary>
		/// Create a new radio object.
		/// </summary>
		/// <param name="host">The host running FlDigi.</param>
		public RadioFlDigi(string host) {
			m_Host = host;
			m_Quit = false;
			m_Thread = new Thread(WorkerThread) { Name = "RadioFlDigi.Thread" };
			m_Thread.Start();
		}

		/// <summary>
		/// Dispose of the radio object.
		/// </summary>
		public void Dispose() {
			m_Quit = true;
			m_Thread.Join();
			m_Radio = null;
			m_Thread = null;
		}
		#endregion

		#region Utilities
		private void WorkerThread() {
			while (!m_Quit) {
				try {
					m_Radio = new FlDigi(m_Host);
					while (!m_Quit) {
						Frequency = m_Radio.Frequency;
#if VERBOSE_DEBUG
						Debug.WriteLine("DEBUG: Read FlDigi frequency: " + Frequency);
#endif
						Thread.Sleep(500);
					}
				} catch {
					// be nice between failures
					Thread.Sleep(1000);

					// clear the frequency
					Frequency = 0m;
				}
			}
			Frequency = 0m;
		}
		#endregion
	}
}
